@@ -437,9 +437,8 @@ class BaseServer(object):
         cost = (self.sdb.box_usage * .14) * (60*60*24*30.4) / (running_time)
         active_requests_by_host = self.rq.getActiveRequestsByHost()
         pending_requests_by_host = self.rq.getPendingRequestsByHost()
-        load_average = [str(Decimal(str(x), 2)) for x in os.getloadavg()]
         data = {
-            "load_avg":os.getloadavg(),
+            "load_avg":[str(Decimal(str(x), 2)) for x in os.getloadavg()],
             "running_time":running_time,
             "cost":cost,
             "active_requests_by_host":active_requests_by_host,
